@@ -1,5 +1,5 @@
 from os import listdir
-from subprocess import check_output
+from subprocess import check_output, CalledProcessError, STDOUT
 import traceback
 import sys
 
@@ -46,13 +46,18 @@ class System:
     def run(self, *args):
         try:
             print("running: '{}'".format(self.srepr(*args)))
-            output = check_output(*args).strip()
+            output = check_output(*args, stderr=STDOUT).strip()
             if output:
                 print(output)
             return True
+        except CalledProcessError as e:
+            if e.output.strip():
+                print(e.output.strip())
+            print 'error: args: {}, message: {}, exit code: {}'.format(e.args, e.message, e.returncode)
         except Exception as e:
             print 'error: args: {}, message: {}'.format(e.args, e.message)
-            return False
+
+        return False
 
     def srepr(self, list):
         if isinstance(list, basestring):
